# Deep-Motilidad

This package contains several commands and utilities to easily use the classification and semantic segmentation models in motility images. 

## 🚀 Getting Started

To start using this package, install it using `pip`:

For example, for installing it in Ubuntu use:
```bash
pip3 install Deep-Motilidad
```

It is recommended to install it globally and not inside virtual environments.
Have been tested in Windows, Linux and MacOS.

## 👩‍💻 Usage
This package makes easier the use of the best trained model. For that purpose you have available 2 commands:
* `deep-motilidad classification <inputFolder> <outputFolder>` This method predict in all the images of a folder.
* `deep-motilidad segmentation <inputFolder> <outputFolder>` This method predict in all the images of a folder.


